==> hlw-core-0.0.2-20250422.075438-9-sources.jar: cn/gtmap/hlw/core/model/GxYyYypzxx.java <==
package cn.gtmap.hlw.core.model;

import com.baomidou.mybatisplus.extension.activerecord.Model;

import java.io.Serializable;
import java.util.Date;

/**
 * (GxYyYypzxx)表实体类
 *
 * @author makejava
 * @since 2024-02-26 15:23:10
 */
@SuppressWarnings("serial")
public class GxYyYypzxx extends Model<GxYyYypzxx> {

    private String id;

    /**
     * 登记中心代码（gx_yy_djzx.djzxdm）
     */
    private String djzxdm;

    /**
     * 日期（gx_yy_jjr.rq）
     */
    private String rq;

    /**
     * 起始时间
     */
    private String qssj;

    /**
     * 结束时间
     */
    private String jssj;

    /**
     * 预约人数
     */
    private Integer yyrs;

    /**
     * 创建时间
     */
    private Date cjsj;

    /**
     * 星期
     */
    private String xq;


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getDjzxdm() {
        return djzxdm;
    }

    public void setDjzxdm(String djzxdm) {
        this.djzxdm = djzxdm;
    }

    public String getRq() {
        return rq;
    }

    public void setRq(String rq) {
        this.rq = rq;
    }

    public String getQssj() {
        return qssj;
    }

    public void setQssj(String qssj) {
        this.qssj = qssj;
    }

    public String getJssj() {
        return jssj;
    }

    public void setJssj(String jssj) {
        this.jssj = jssj;
    }

    public Integer getYyrs() {
        return yyrs;
    }

    public void setYyrs(Integer yyrs) {
        this.yyrs = yyrs;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getXq() {
        return xq;
    }

    public void setXq(String xq) {
        this.xq = xq;
    }

    /**
     * 获取主键值
     *
     * @return 主键值
     */
    @Override
    protected Serializable pkVal() {
        return this.id;
    }
}

==> hlw-core-0.0.2-20251119.064409-171-sources.jar: cn/gtmap/hlw/core/model/GxYyYypzxx.java <==
package cn.gtmap.hlw.core.model;

import com.baomidou.mybatisplus.extension.activerecord.Model;

import java.io.Serializable;
import java.util.Date;

/**
 * (GxYyYypzxx)表实体类
 *
 * @author makejava
 * @since 2024-02-26 15:23:10
 */
@SuppressWarnings("serial")
public class GxYyYypzxx extends Model<GxYyYypzxx> {

    private String id;

    /**
     * 登记中心代码（gx_yy_djzx.djzxdm）
     */
    private String djzxdm;

    /**
     * 日期（gx_yy_jjr.rq）
     */
    private String rq;

    /**
     * 起始时间
     */
    private String qssj;

    /**
     * 结束时间
     */
    private String jssj;

    /**
     * 预约人数
     */
    private Integer yyrs;

    /**
     * 创建时间
     */
    private Date cjsj;

    /**
     * 星期
     */
    private String xq;

    /**
     * 年份
     */
    private String nf;


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getNf() {
        return nf;
    }

    public void setNf(String nf) {
        this.nf = nf;
    }

    public String getDjzxdm() {
        return djzxdm;
    }

    public void setDjzxdm(String djzxdm) {
        this.djzxdm = djzxdm;
    }

    public String getRq() {
        return rq;
    }

    public void setRq(String rq) {
        this.rq = rq;
    }

    public String getQssj() {
        return qssj;
    }

    public void setQssj(String qssj) {
        this.qssj = qssj;
    }

    public String getJssj() {
        return jssj;
    }

    public void setJssj(String jssj) {
        this.jssj = jssj;
    }

    public Integer getYyrs() {
        return yyrs;
    }

    public void setYyrs(Integer yyrs) {
        this.yyrs = yyrs;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getXq() {
        return xq;
    }

    public void setXq(String xq) {
        this.xq = xq;
    }

    /**
     * 获取主键值
     *
     * @return 主键值
     */
    @Override
    public Serializable pkVal() {
        return this.id;
    }
}
